@@ -4,39 +4,40 @@ from ..lib.handler.github_handler import GithubHandler
 from ..lib.logger import Logger
 from ..lib.handler import git_handler as git
 from ..lib.handler.captainhook_handler import CaptainHook
-import os
+from ..lib.handler.slack_handler import SlackHandler
 import sys
 import readline
-import re
 
 youtrack = YoutrackHandler()
 github = GithubHandler()
 logger = Logger()
+slack = SlackHandler()
 
 try:
     captainhook = CaptainHook()
     users = captainhook.get_users_list().json()
 except:
     logger.error(
-        "Non riesco ad ottenere la lista degli utenti da captainhook. Agiungere i reviewer dal sito GitHub")
+        "Non riesco ad ottenere la lista degli utenti da captainhook.\
+        Controlla di avere attiva la VPN. Se il problema persiste aggiungi i reviewer dal sito GitHub")
     sys.exit(-1)
 
 
 def entrypoint(args):
-
-    repo = os.path.basename(os.getcwd())
     branch_name = git.current_branch_name()
-    github_reviewers = []
 
-    pull = github.get_pr_from_branch(repo, branch_name)
+    github_reviewers = []
+    slack_reviewers = []
+
+    pull = github.get_pr_from_branch(args.project, branch_name)
 
     if pull.totalCount:
         pr = pull[0]
-        logger.info('Trovata PR numero {} sul branch {} sul repo {}'.format(
-            pr.number, branch_name, repo))
+        logger.info('Ho trovato la pull request numero {} per il branch {} sul repo {}'.format(
+            pr.number, branch_name, args.project))
     else:
         logger.error(
-            'Nessuna PR aperta trovata con il branch {}'.format(branch_name))
+            'Nessuna pull request aperta trovata per il branch {}'.format(branch_name))
         sys.exit(-1)
 
     youtrack_reviewers = ask_reviewer()
@@ -45,28 +46,31 @@ def entrypoint(args):
         for user in users:
             if user["youtrack"] == rev:
                 github_reviewers.append(user["github"])
+                slack_reviewers.append(user["slack"])
 
     pr.create_review_request(github_reviewers)
+    logger.info('Aggiungo reviewers su GitHub')
 
-    regex = '[A-Z]+-[0-9]+'
-    if re.search(regex, pr.title):
-        id_card = re.findall(regex, pr.title)[0]
-        if not youtrack.validate_issue(id_card):
-            logger.error("La card {} non esiste".format(id_card))
-            sys.exit(-1)
-        else:
-            logger.info(
-                'Sposto la card {} in review su youtrack e aggiungo i tag degli utenti'.format(id_card))
-            youtrack.update_state(id_card, 'Review')
-            for rev in youtrack_reviewers:
-                try:
-                    youtrack.add_tag(id_card, "review:{}".format(rev))
-                except BaseException as e:
-                    logger.warning(
-                        "Non sono riuscito ad aggiungere i tag di review: {}".format(e))
-                    sys.exit(-1)
+    for rev in slack_reviewers:
+        slack.post('#review', '<@{}> {}'.format(
+            rev, pr.html_url))
+    logger.info('Cito reviewers su Slack')
+
+    youtrack_id = youtrack.get_card_from_name(pr.title)
+
+    if youtrack_id:
+        logger.info(
+            'Sposto la card {} in review su youtrack e aggiungo i tag degli utenti'.format(youtrack_id))
+        youtrack.update_state(youtrack_id, 'Review')
+        for rev in youtrack_reviewers:
+            try:
+                youtrack.add_tag(youtrack_id, "review:{}".format(rev))
+            except BaseException as e:
+                logger.warning(
+                    "Non sono riuscito ad aggiungere i tag di review: {}".format(e))
+                sys.exit(-1)
     else:
-        logger.warning('Reviewers inseriti su GitHub. Nessuna card collegata.')
+        logger.warning('Reviewers inseriti SOLO su GitHub. Nessuna card collegata o card nel nome del branch inesistente su YouTrack.')
 
 
 def ask_reviewer():
@@ -80,7 +84,7 @@ def ask_reviewer():
 
     if len(youtrack_reviewers) < 1:
         logger.warning("Devi inserire almeno un reviewer")
-        ask_reviewer()
+        return ask_reviewer()
     else:
         return youtrack_reviewers
 
