@@ -12,7 +12,7 @@ config = Config().load()
 
 
 def _get_path(repo):
-    return "{}/{}".format(config['user']['projects_home'], repo)
+    return os.path.join(config['user']['projects_home'], repo)
 
 
 def clone(repo):
@@ -44,7 +44,7 @@ def commit(repo, commit_message='', dummy=False):
     try:
         if dummy:
             subprocess.run(['git', 'commit',  '--allow-empty', '-m',
-                            '[SKIP CI] dummy'], cwd=_get_path(repo), check=True)
+                            commit_message], cwd=_get_path(repo), check=True)
         else:
             subprocess.run(['git', 'commit',  '-am', commit_message],
                            cwd=_get_path(repo), check=True)
@@ -74,9 +74,10 @@ def pull(repo, rebase=False):
         sys.exit(-1)
 
 
-def fetch(repo):
+def fetch(repo, remote='origin'):
     try:
         subprocess.run(['git', 'fetch'], cwd=_get_path(repo), check=True)
+        subprocess.run(['git', 'fetch', '-p', remote], cwd=_get_path(repo), check=True)
     except (CalledProcessError) as e:
         logger.error("Errore eseguendo il comando: {}".format(e))
         sys.exit(-1)
@@ -98,8 +99,9 @@ def check_repo_cloned(repo):
 def delete_remote_branch(repo, branch):
     try:
         push(repo, ":{}".format(branch))
+        return True
     except BaseException:
-        return None
+        return False
 
 
 def get_git_username():
@@ -117,6 +119,15 @@ def get_last_tag(project):
     return subprocess.check_output(["git", "describe", "--abbrev=0", "--tags"]).decode('ascii').strip()
 
 
+def search_remote_branch(repo, regex):
+    try:
+        output = subprocess.run(['git', 'branch', '-r', '--list', regex],
+                       cwd=_get_path(repo), check=True, stdout=subprocess.PIPE)
+
+        return output.stdout.decode("utf-8").strip('\n').strip().strip('origin/')
+    except (CalledProcessError):
+        return ""
+
 def remote_branch_exists(repo, branch):
     try:
         subprocess.run(['git', 'show-ref', '--quiet', 'refs/remotes/origin/{}'.format(branch)],
