@@ -1,4 +1,5 @@
 from PyInquirer import prompt
+import sys
 
 
 def ask_confirm(text, default=True):
@@ -61,3 +62,8 @@ def ask_choices(question_text, choices, default_text=""):
 
     answer = prompt(questions)
     return answer['value']
+
+
+def project_confirmation(project):
+    if not ask_confirm("Vuoi continuare sul progetto {}?".format(project)):
+        sys.exit(-1)
